Authors
=======

FauxFactory is written and maintained by Og Maciel and various
contributors.

Development Lead
----------------

- Og Maciel `@omaciel <https://github.com/omaciel/>`_

Contributors
------------

- Corey Welton `@cswiii <https://github.com/cswiii/>`_
- Elyézer Rezende `@elyezer <https://github.com/elyezer/>`_
- Jefferson Fausto Vaz `@faustovaz <https://github.com/faustovaz/>`_
- Jeremy Audet `@Ichimonji10 <https://github.com/Ichimonji10/>`_
- Kedar Bidarkar  `@kbidarkar <https://github.com/kbidarkar/>`_
- Sachin Ghai `@sghai <https://github.com/sghai/>`_
